@@ -22,6 +22,27 @@ module NumRu
     print "EOF engin is #{@@EOF_engin}\n" if $DEBUG
 
     module_function
+
+    # = Calculate EOF vectors and contribution rate
+    # call-seq:
+    #  NumRu::GAnalysis.eof(gphys, dim0[, dim1, ..., dimN[, opts]]) => [eof, rate]
+    #
+    # == Arguments
+    # +gphys+:: GPhys object to be calculated its EOF
+    # +dim0+, ..., +dimN+:: dimension name (String) or number (Ingeter) to calculate variance or covariance, and those dimensions are not contained in the result EOF vectors.
+    # +opts+:: a Hash object whose key is String or Symbol. The following options are available:
+    #   * nmodes: Integer, number of EOF modes to be calculate (default all EOF modes)
+    #   * weight: GPhys or NArray, weight vector
+    #              +gphys+ is multiplied by the weight vector before calculation of variance covariance matrix
+    #              and the result eigen vectors are divided by the vector.
+    #              If weight vector is not set,
+    #                 it is cosine of latitude when the first two axes of the +gphys+ are "lon" and "lat" and +disable_weight+ option is not +true+,
+    #                 else 1.
+    #   * disable_weight: See weight option.
+    #
+    # == Return values
+    # +eof+:: GPhys object for array of EOF vectors.
+    # +rate+:: GPhys object for array of contribution rate correspoinding to the EOF vectors.
     def eof(gphys, *args)
 
       unless defined?(@@EOF_engin)
@@ -54,7 +75,7 @@ module NumRu
       index = NArray.object(gphys.rank)
       index[dims] = true
 
-      if w = opts[:weight]
+      if w = (opts[:weight] || opts["weight"])
         if GPhys === w
           w = w.val
         end
@@ -67,7 +88,7 @@ module NumRu
         w /= w.mean
         w.reshape!(n)
       else
-        if !opts[:disable_weight] && /^lon/ =~ new_grid.coord(0).name && /^lat/ =~ new_grid.coord(1).name
+        if !(opts[:disable_weight]||opts["disable_weight"]) && /^lon/ =~ new_grid.coord(0).name && /^lat/ =~ new_grid.coord(1).name
           rad = NumRu::Units.new("radian")
           nlon = new_grid.coord(0).length
           lat = new_grid.coord(1).convert_units(rad).val
@@ -102,7 +123,7 @@ module NumRu
       ary.mul!(w.reshape(1,n)) if w
 
 
-      nmodes = opts["nmodes"] || n
+      nmodes = opts[:nmodes] || opts["nmodes"] || n
       case @@EOF_engin
       when "ssl2"
         print "start calc covariance matrix\n" if $DEBUG
@@ -133,9 +154,11 @@ module NumRu
         print "start calc eigen vector\n" if $DEBUG
         case nary.typecode
         when NArray::DFLOAT
-          val, vec = NumRu::Lapack.dsyevr(nary, "jobz" => "V", "uplo"=>"L", "range"=>"I", "il"=>n-nmodes+1, "iu"=>n)
+	  m, val, vec, isuppz, work, iwork, info, = NumRu::Lapack.dsyevr("V", "I", "L", nary, 0, 0, n-nmodes+1, n, 0.0, -1, -1)
+	  m, val, vec, = NumRu::Lapack.dsyevr("V", "I", "L", nary, 0, 0, n-nmodes+1, n, 0.0, work[0], iwork[0])
         when NArray::SFLOAT
-          val, vec = NumRu::Lapack.ssyevr(nary, "jobz" => "V", "uplo"=>"L", "range"=>"I", "il"=>n-nmodes+1, "iu"=>n)
+	  m, val, vec, isuppz, work, iwork, info, = NumRu::Lapack.ssyevr("V", "I", "L", nary, 0, 0, n-nmodes+1, n, 0.0, -1, -1)
+	  m, val, vec, = NumRu::Lapack.ssyevr("V", "I", "L", nary, 0, 0, n-nmodes+1, n, 0.0, work[0], iwork[0])
         end
         val = val[-1..0]
         vec = vec[true,-1..0]
@@ -149,6 +172,7 @@ module NumRu
         ary = nil # for GC
         print "start calc eigen vector\n" if $DEBUG
         val, vec = GSL::Eigen::symmv(nary.to_gm)
+        GSL::Eigen.symmv_sort(val, vec, GSL::Eigen::SORT_VAL_DESC)
         vec = vec.to_na[0...nmodes,true].transpose(1,0)
         val = val.to_na
         total_var = val.sum
@@ -177,6 +201,23 @@ module NumRu
       return [eof, rate]
     end
 
+    def eof2(gphys1, gphys2, *args)
+      if Hash === args[-1]
+        opts = args[-1]
+      else
+        opts = Hash.new
+      end
+      raise ArgumentError, "The 1st arg must be a GPhys of rank 1: arg1 = #{gphys1.inspect}" unless gphys1.rank==1
+      raise ArgumentError, "The 2nd arg must be a GPhys of rank 1: arg2 = #{gphys2.inspect}" unless gphys2.rank==1
+      raise ArgumentError, "The 1st and 2nd args must have the same length: #{gphys1.length}!=#{gphys2.length}" unless gphys2.rank==1
+      nam = NArrayMiss.new(gphys1.typecode, 2, gphys1.length)
+      nam[0,true] = gphys1.val
+      nam[1,true] = gphys2.val
+      gphys = GPhys.new(Grid.new(Axis.new.set_pos(VArray.new(NArray[0,1],{},"var")),
+                                 gphys1.axis(0)),
+                        VArray.new(nam,gphys1.data.attr_copy,gphys1.name))
+      eof(gphys, 1, opts)
+    end
   end
 
   class GPhys
@@ -188,6 +229,7 @@ module NumRu
 end
 
 
+#:enddoc
 
 if  $0 == __FILE__
   require "numru/ggraph"
@@ -224,6 +266,33 @@ if  $0 == __FILE__
   DCL::sgplzu([eof2[0],-eof2[0]],[eof2[1],-eof2[1]], 1, 43)
 
   DCL::usdaxs
+  DCL::uxsttl("T","test of GAnalysis::eof",0)
+
+  # TEST OF GAnalysis::eof2
+
+  vary1 = VArray.new(ary[0,true], { }, "test")
+  gphys1 = GPhys.new(Grid.new(axis1), vary1)
+  vary2 = VArray.new(ary[1,true], { }, "test")
+  gphys2 = GPhys.new(Grid.new(axis1), vary2)
+
+  eof,rate = GAnalysis.eof2(gphys1,gphys2)
+
+  max = 5
+  DCL::grfrm
+  DCL::grsvpt(0.1,0.9,0.1,0.9)
+  DCL::grswnd(-max,max,-max,max)
+  DCL::grstrn(1)
+  DCL::grstrf
+
+  DCL::sgpmzu(ary[0,true],ary[1,true],1,1,0.01)
+
+  eof1 = eof[true,0].val
+  eof2 = eof[true,1].val
+  DCL::sgplzu([eof1[0],-eof1[0]],[eof1[1],-eof1[1]], 1, 23)
+  DCL::sgplzu([eof2[0],-eof2[0]],[eof2[1],-eof2[1]], 1, 43)
+
+  DCL::usdaxs
+  DCL::uxsttl("T","test of GAnalysis::eof2",0)
 
   DCL::grcls
 end
