@@ -317,6 +317,13 @@ simulation. The 3rd is not physical and may not be considered as
       * Float if the modulo is defined
       * nil if modulo is not found
 
+---cyclic_extendible?
+    Returns whether the axis is cyclic and appropriate to extend.
+    (Relies on the VArray#axis_cyclic_extendible? method.)
+    
+    RETURN VALUE
+    * true or false
+
 =end
 
 module NumRu
@@ -577,14 +584,16 @@ module NumRu
 	      if units && /(.*) *since *(.*)/ =~ units  
                 calendar = self.pos.get_att('calendar')
                 datetime = UNumeric[cval, units].to_datetime(0.1,calendar)
-                if Units[units] =~ Units['days since 1-1-1'] # s,hour,day,..
-		  info_lost = datetime.strftime(@@strftime_fmt || '%Y-%m-%d %H:%M:%S%z')
-		elsif Units[units] =~ Units['months since 1-1-1'] # year,month,pentad,..
-		  if /mon/ =~ units.to_s || /year/ =~ units.to_s
-		    info_lost = datetime.strftime(@@strftime_fmt || '%Y-%m')
-		  else  # maybe pentad
-		    info_lost = datetime.strftime(@@strftime_fmt || '%Y-%m-%d')
-		  end
+                if datetime
+                  if Units[units] =~ Units['days since 1-1-1'] # s,hour,day,..
+                    info_lost = datetime.strftime(@@strftime_fmt || '%Y-%m-%d %H:%M:%S%z')
+                  elsif Units[units] =~ Units['months since 1-1-1'] # year,month,pentad,..
+                    if /mon/ =~ units.to_s || /year/ =~ units.to_s
+                      info_lost = datetime.strftime(@@strftime_fmt || '%Y-%m')
+                    else  # maybe pentad
+                      info_lost = datetime.strftime(@@strftime_fmt || '%Y-%m-%d')
+                    end
+                  end
                 end
 		info_lost_set = true
 	      end
@@ -813,6 +822,10 @@ module NumRu
 	@pos.axis_modulo
       end
 
+      def cyclic_extendible?
+	@pos.axis_cyclic?
+      end
+
       #########  private methods ####################################
 
       private
