@@ -357,6 +357,24 @@
     NOTE
     * Algorithm implementation is done in Axis class.
 
+
+---eddy(*dim)
+    Deviation from mean
+
+    ARGUMENT
+    * a list of dimensions (including none) [Integer or String] along which
+      the mean is taken.
+
+    RETURN VALUE
+    * a GPhys
+
+    NOTE
+    * Simply defined as
+
+        def eddy(*dim)
+          self - self.mean(*dim)
+        end
+
 ---first1D
     Returns a 1D subset selecting the first elements of 2nd, 3rd, ..
     dimensions, i.e., self[true, 0, 0, ...]. (For graphics)
@@ -642,6 +660,14 @@ module NumRu
       def lost_axes
 	 @grid.lost_axes
       end
+      def set_lost_axes( lost )
+        @grid.set_lost_axes( lost )
+        self
+      end
+      def add_lost_axes( lost )
+        @grid.add_lost_axes( lost )
+        self
+      end
       def dim_index( dimname )
 	 @grid.dim_index( dimname )
       end
@@ -670,6 +696,12 @@ module NumRu
         @grid.assoc_coords
       end
 
+      ## Basic numerical operations that are not defined on the VArray level
+
+      def eddy(*dim)
+        self - self.mean(*dim)
+      end
+
       ## For graphics -->
       def first3D
 	raise "rank less than 3" if rank < 3
@@ -942,15 +974,15 @@ module NumRu
 		  end
 		  grid.set_axis(nm,gphyses[0].axis(nm))
 		}
-		if rs.data[0..0,false].val.respond_to?(:set_mask)
+		if ( (vtst=rs.data[0..0,false].val).respond_to?(:set_mask) )
                    # DEVELOPPER'S NOTE (2006/08/15 horinout). 
                    # Here, [0..0,false] is to take the minimum subset,
                    # and respond_to?(:set_mask) is used to check whether
                    # the data array is compatible to NArrayMiss
-		  vary = VArray.new(NArrayMiss.new(rs.ntype, *grid.shape), 
+		  vary = VArray.new(NArrayMiss.new(vtst.typecode, *grid.shape), 
 				    rs.data)
 		else
-		  vary = VArray.new(NArray.new(rs.ntype, *grid.shape), rs.data)
+		  vary = VArray.new(NArray.new(vtst.typecode, *grid.shape), rs.data)
 		end
 		results_whole.push( GPhys.new( grid, vary ) )
 	      end
