@@ -41,12 +41,12 @@ module NumRu
 
         axes = Array.new
         dns = var.dim_names
-        lonlat = (dns.include?("lon") && dns.include?("lat"))
+        lonlat2d = dns.include?("lon") && var.dim("lon").val(:full).rank > 1
         dns.each{|dn|
           dim = var.dim(dn)
           attr = Hash.new
           dim.att_names.each{|an| attr[an] = dim.att(an)}
-          dn << "_ref" if lonlat && /\A(lon|lat)\z/ =~ dn
+          dn << "_ref" if lonlat2d && /\A(lon|lat)\z/ =~ dn
           axpos = VArray.new(dim.val(:reference), attr, dn)
           axis = Axis.new(false, true)
           axis.set_pos(axpos)
@@ -55,18 +55,49 @@ module NumRu
         grid = Grid.new(*axes)
         gphys = GPhys.new(grid, data)
 
-        if lonlat
+        if lonlat2d
+          puts "gphys_nusdas_io.rb: assoc_coords are introduced" if $DEBUG
           x = gphys.axis("lon_ref")
           y = gphys.axis("lat_ref")
           xy = Grid.new(x,y)
-          vlon = VArray.new(var.dim("lon").val(:full), y.pos.attr_copy, "lon")
+          vlon = VArray.new(var.dim("lon").val(:full), x.pos.attr_copy, "lon")
           vlat = VArray.new(var.dim("lat").val(:full), y.pos.attr_copy, "lat")
           glon = GPhys.new(xy, vlon)
           glat = GPhys.new(xy, vlat)
-          ary = [glon,glat]
-          gphys.set_assoc_coords(ary)
+          tmp_assoc_coords = [glon,glat]
         end
 
+        if var.dim_names.include?("z") && var.att("vertical_grid") =~ /[Zz]\*/ # Z* coordinate
+          puts "gphys_nusdas_io.rb: assoc_coords are introduced" if $DEBUG
+          x = gphys.axis("lon_ref")
+          y = gphys.axis("lat_ref")
+          z = gphys.axis("z")
+          xyz = Grid.new(x,y,z)
+          zrp, zrw, vctrans_p, vctrans_w, dvtrans_p, dvtrans_w = var.dim("z").val(:full)
+          zs = nusdas.var("ZSsrf") # terrain
+          case zs.rank
+          when 2
+            na_zs = zs.get
+          when 3
+            na_zs = zs[true,true,0]
+          else
+            raise "BUG: rank of ZSsrf > 3"
+          end
+          na_zs = na_zs.newdim!(-1)
+          z3d = na_zs + (1 + na_zs * dvtrans_p.newdim(0,0)) * zrp.newdim(0,0)
+          vz3d = VArray.new(z3d, z.pos.attr_copy, "z3d")
+          gz3d = GPhys.new(xyz, vz3d)
+          tmp_assoc_coords ||= []
+          tmp_assoc_coords.push(gz3d)
+          gphys.set_att("zrp",zrp)
+          gphys.set_att("zrw",zrw)
+          gphys.set_att("vctrans_p",vctrans_p)
+          gphys.set_att("vctrans_w",vctrans_w)
+          gphys.set_att("dvtrans_p",dvtrans_p)
+          gphys.set_att("dvtrans_w",dvtrans_w)
+        end
+        gphys.set_assoc_coords(tmp_assoc_coords) if tmp_assoc_coords
+
         return gphys
       end
       module_function :open
