@@ -263,6 +263,12 @@ NOMENCLATURE
       * Float if the modulo is defined
       * nil if modulo is not found
 
+---axis_cyclic_extendible?
+    (meaningful only if self is a coordinate variable.) 
+    Returns true if self is cyclic and it is suitable to exend
+    cyclically (having the distance between both ends 
+    equal to (modulo - dx), where dx is the mean increment).
+
 ---coerce(other)
     For Numeric operators. (If you do not know it, see a manual or book of Ruby)
 
@@ -621,7 +627,7 @@ These methods returns a NArray (not a VArray).
 	when /circular/i
 	  true
 	when nil     # 'topology' not defined
-	  if attr['units'] == 'degrees_east'
+	  if /degrees?_east/ =~ attr['units']
 	    true     # special treatment a common convention for the earth
 	  else
 	    nil      # not defined --> nil
@@ -641,15 +647,34 @@ These methods returns a NArray (not a VArray).
 	  else
 	    attval[0]
 	  end
-	else
-	  if attr['units'] == 'degrees_east'
-	    360.0     # special treatment a common convention for the earth
-	  else
-	    nil      # not defined --> nil
-	  end
+	elsif /degrees?_east/ =~ attr['units']
+          360.0     # special treatment: a common convention for the earth
+        elsif (tp = attr['topology']) and (/circular/i =~ tp)
+          un = Units[attr['units']]
+          if un == Units['degrees']
+	    360.0
+          elsif un == Units['radian']
+            2*Math::PI
+          else
+            nil    # cannot guess --> nil
+          end
+        else
+          nil      # not defined --> nil
 	end
       end
 
+      def axis_cyclic_extendible?
+        modulo = axis_modulo
+        return false if !modulo
+        v = val
+        width = (v[-1] - v[0]).abs
+	dx = width / (length-1)
+	eps = 1e-4
+	modulo = modulo.abs
+	extendible = ( ((width+dx) - modulo).abs < eps*modulo )
+        return extendible
+      end
+
       ### < NArray methods > ###
 
       ## ToDo: implement units handling
@@ -1068,11 +1093,17 @@ if $0 == __FILE__
 
    p '*axis conventions*'
    p vx = VArray.new( NArray.int(6).indgen!, nil, 'x' )
-   vx.set_att('topology','circular')
+
+   vx.put_att("topology","circular")
    vx.set_att('modulo',[360.0])
    vx.set_att('positive','down')
    p vx.axis_draw_positive, vx.axis_cyclic?, vx.axis_modulo
 
+   p '   cyclic extendible:'
+   p vx.axis_cyclic_extendible?
+   vx.set_att('modulo',[6.0])
+   p vx.axis_cyclic_extendible?
+
    p '*typecode*'
    p vx.typecode, vx[0..1].typecode
 end
