@@ -148,10 +148,6 @@ module NumRu
       # "bounds=#{@bound_idx.collect{|b| b[1..-2]}.inspect}"
     end
 
-    def ntype
-      @first_vary.ntype
-    end
-
     def shape
       @shape
     end
@@ -174,9 +170,9 @@ module NumRu
 	v = @varrays[*index].val
 	if !val
 	  if NArray===v
-	    val = NArray.new(self.ntype,*@shape)
+	    val = NArray.new(v.typecode,*@shape)
 	  elsif NArrayMiss===v
-	    val = NArrayMiss.new(self.ntype,*@shape)
+	    val = NArrayMiss.new(v.typecode,*@shape)
 	  else
 	    raise TypeError, "Unexpected type #{v.class}"
 	  end
@@ -224,6 +220,9 @@ module NumRu
       val
     end
 
+#    def ntype
+#      @first_vary.ntype
+#    end
     def ntype
       __ntype(typecode)
     end
